# Parametric Models

## Outliers

Specify outliers using the class type:

```python
class_type = "outliers"
```

Outliers are sampled from the 2D space defined by \\(x_r \times y_r\\), where \\(x_r\\) (x range) is the closed interval of values that x can take and \\(y_r\\) (y range) is the closed interval of values that y can take.

```python
"outliers": {
    "x_r": (-2.5, 2.5),
    "y_r": (-2.5, 2.5)
}
```

## Conics

### Circles

Specify circles using the class type:

```python
class_type = "circles"
```

Circles are generated by uniformly sampling a center and a radius from the closed intervals specified by the user.  
The default values are:

```python
"circles": {
    "radius_r": (0.5, 1.5),
    "x_center_r": (-1.0, 1.0),
    "y_center_r": (-1.0, 1.0),
}
```

### Lines

Specify lines using the class type:

```python
class_type = "lines"
```

Lines are generated by randomly sampling two points in the 2D space \\(x_r \times y_r\\) to define slope and intercept, and then sampling points belonging to this line. Each point of the line is ensured to belong to the 2D space \\(x_r \times y_r\\).

```python
"lines": {
    "x_r": (-2.5, 2.5),
    "y_r": (-2.5, 2.5)
}
```

### Ellipses

Specify ellipses using the class type:

```python
class_type = "ellipses"
```

Ellipses are generated by uniformly sampling a center and a radius from the closed intervals specified by the user, and then applying horizontal stretch/shrinkage to the sampled circle.  
The default values are:

```python
"ellipses": {
    "radius_r": (0.5, 1.5),
    "x_center_r": (-1, 1),
    "y_center_r": (-1, 1),
    "width_r": (0.1, 1),
    "height_r": (0.1, 1)
}
```

### Any Conic

Specify any conic using the class type:

```python
class_type = "conics"
```

This option randomly samples models from all the classes specified above. Note: Hyperbola is not implemented yet.
